@@ -207,7 +207,7 @@ impl CsrfHandler {
     }
 
     fn find_csrf_cookie(&self, req: &Request) -> Option<UnencryptedCsrfCookie> {
-        req.get_cookie(&self.cookie_name)
+        req.cookie(&self.cookie_name)
             .and_then(|c| match base64::decode(c.value().as_bytes()) {
                 Ok(value) => Some(value),
                 Err(e) => {
@@ -260,7 +260,7 @@ impl CsrfHandler {
     }
 
     async fn find_csrf_token_in_form(&self, req: &mut Request) -> Option<Vec<u8>> {
-        req.get_form::<String>(&self.form_field)
+        req.form::<String>(&self.form_field)
             .await
             .and_then(|v| base64::decode_config(v.as_bytes(), base64::URL_SAFE).ok())
     }
@@ -379,7 +379,7 @@ mod tests {
 
         assert_eq!(res.status_code().unwrap(), StatusCode::OK);
         assert_ne!(res.take_text().await.unwrap(), "");
-        assert_ne!(res.get_cookie("salvo.extra.csrf"), None);
+        assert_ne!(res.cookie("salvo.extra.csrf"), None);
     }
 
     #[tokio::test]
@@ -400,7 +400,7 @@ mod tests {
         assert_eq!(res.status_code().unwrap(), StatusCode::OK);
 
         let csrf_token = res.take_text().await.unwrap();
-        let cookie = res.get_cookie("salvo.extra.csrf").unwrap();
+        let cookie = res.cookie("salvo.extra.csrf").unwrap();
 
         let req: Request = hyper::Request::builder()
             .method("POST")
@@ -442,7 +442,7 @@ mod tests {
         assert_eq!(res.status_code().unwrap(), StatusCode::OK);
 
         let csrf_token = res.take_text().await.unwrap();
-        let cookie = res.get_cookie("salvo.extra.csrf").unwrap();
+        let cookie = res.cookie("salvo.extra.csrf").unwrap();
 
         let req: Request = hyper::Request::builder()
             .method("POST")
@@ -484,7 +484,7 @@ mod tests {
         assert_eq!(res.status_code().unwrap(), StatusCode::OK);
 
         let csrf_token = res.take_text().await.unwrap();
-        let cookie = res.get_cookie("salvo.extra.csrf").unwrap();
+        let cookie = res.cookie("salvo.extra.csrf").unwrap();
 
         let req: Request = hyper::Request::builder()
             .method("POST")
@@ -524,7 +524,7 @@ mod tests {
         assert_eq!(res.status_code().unwrap(), StatusCode::OK);
 
         let csrf_token = res.take_text().await.unwrap();
-        let cookie = res.get_cookie("salvo.extra.csrf").unwrap();
+        let cookie = res.cookie("salvo.extra.csrf").unwrap();
 
         let req: Request = hyper::Request::builder()
             .method("POST")
@@ -565,7 +565,7 @@ mod tests {
         assert_eq!(res.status_code().unwrap(), StatusCode::OK);
 
         let csrf_token = res.take_text().await.unwrap();
-        let cookie = res.get_cookie("salvo.extra.csrf").unwrap();
+        let cookie = res.cookie("salvo.extra.csrf").unwrap();
 
         let req: Request = hyper::Request::builder()
             .method("POST")
@@ -606,7 +606,7 @@ mod tests {
         assert_eq!(res.status_code().unwrap(), StatusCode::OK);
 
         let csrf_token = res.take_text().await.unwrap();
-        let cookie = res.get_cookie("salvo.extra.csrf").unwrap();
+        let cookie = res.cookie("salvo.extra.csrf").unwrap();
 
         let req: Request = hyper::Request::builder()
             .method("POST")
@@ -646,7 +646,7 @@ mod tests {
         let res = service.handle(req).await;
         assert_eq!(res.status_code().unwrap(), StatusCode::OK);
 
-        let cookie = res.get_cookie("salvo.extra.csrf").unwrap();
+        let cookie = res.cookie("salvo.extra.csrf").unwrap();
 
         let req: Request = hyper::Request::builder()
             .method("POST")
@@ -686,7 +686,7 @@ mod tests {
         let res = service.handle(req).await;
         assert_eq!(res.status_code().unwrap(), StatusCode::OK);
 
-        let cookie = res.get_cookie("salvo.extra.csrf").unwrap();
+        let cookie = res.cookie("salvo.extra.csrf").unwrap();
 
         let req: Request = hyper::Request::builder()
             .method("POST")
@@ -735,7 +735,7 @@ mod tests {
             .into();
         let res = service.handle(req).await;
         assert_eq!(res.status_code().unwrap(), StatusCode::OK);
-        let cookie = res.get_cookie("salvo.extra.csrf").unwrap();
+        let cookie = res.cookie("salvo.extra.csrf").unwrap();
 
         let req: Request = hyper::Request::builder()
             .method("POST")
