@@ -7,8 +7,7 @@ use chrono::prelude::*;
 use percent_encoding::{utf8_percent_encode, CONTROLS};
 use salvo_core::async_trait;
 use salvo_core::fs::NamedFile;
-use salvo_core::http::errors::StatusError;
-use salvo_core::http::{Request, Response, StatusCode};
+use salvo_core::http::{Request, Response, StatusCode, StatusError};
 use salvo_core::routing::FlowCtrl;
 use salvo_core::writer::Text;
 use salvo_core::{Depot, Handler};
